@@ -109,18 +109,16 @@ else:
 
 def run(*cmd, **kwargs):
     stdin = kwargs.pop('stdin', None)
-    env = {}
+    env = dict(os.environ)
     for key, value in kwargs.items():
         if key.isupper():
             env[key] = value
             continue
         raise TypeError('{key!r} is an invalid keyword argument for this function'.format(key=key))
-    def preexec_fn():
-        os.environ.update(env)
     kwargs = dict(
-        preexec_fn=preexec_fn,
         stdout=subprocess.PIPE,
         stderr=subprocess.PIPE,
+        env=env,
     )
     if stdin is not None:
         kwargs.update(stdin=subprocess.PIPE)
@@ -172,8 +170,7 @@ class test_documents:
         path = '__nonexistent__'
         try:
             os.stat(path)
-        except OSError:
-            _, ex, _ = sys.exc_info()
+        except OSError as ex:
             c_message = ex.args[1]
         else:
             raise OSError(errno.EEXIST, os.strerror(errno.EEXIST), path)
@@ -200,8 +197,7 @@ class test_documents:
         try:
             with interim_locale(LC_ALL='ja_JP.UTF-8'):
                 os.stat(path)
-        except OSError:
-            _, ex, _ = sys.exc_info()
+        except OSError as ex:
             c_message = ex.args[1]
         else:
             raise OSError(errno.EEXIST, os.strerror(errno.EEXIST), path)
@@ -537,7 +533,7 @@ class test_page_jobs():
             page_job.render(RENDER_COLOR, (0, 0, 10, 10), (0, 0, 10, 10), PixelFormatRgb(), -1)
 
         with assert_raises_regex(MemoryError, r'\AUnable to allocate [0-9]+ bytes for an image memory\Z'):
-            x = int((maxsize//2) ** 0.5)
+            x = int((maxsize // 2) ** 0.5)
             page_job.render(RENDER_COLOR, (0, 0, x, x), (0, 0, x, x), PixelFormatRgb(), 8)
 
         s = page_job.render(RENDER_COLOR, (0, 0, 10, 10), (0, 0, 4, 4), PixelFormatGrey(), 1)
